xGPR
================================
Efficient Bayesian machine learning and discriminant
analysis for sequences, graphs and tabular data.

.. toctree::
  :maxdepth: 1
  
  What is xGPR? <purpose>



Quick start
=====================

.. toctree::
  :maxdepth: 1
  
  Installation <installation>

  How xGPR approximates kernels <approximation_background>

  Quickstart tutorial <basic_tutorial>
  

Examples
=====================

.. toctree::
  :maxdepth: 1

  Examples <notebooks/examples>


Available kernels
=================

.. toctree::
  :maxdepth: 1

   Available kernels <kernel_info/kernel_list>



Advanced / in-depth tutorials
================================

.. toctree::
  :maxdepth: 2

   Datasets & model constructor: in-depth <advanced/initialization_tutorial>

   Tuning hyperparameters: in-depth <advanced/tuning_tutorial>

   Model fitting: in-depth <advanced/fitting_tutorial>

   Clustering and visualizing data <advanced/auxiliary_tutorial>


  

Miscellaneous
==============

.. toctree::
  :maxdepth: 1

  Frequently asked questions <FAQ>

  About / Contact <contact>


Citations
======================
If using xGPR in research intended for publication, please cite either:

Linear-Scaling Kernels for Protein Sequences and Small Molecules Outperform Deep Learning While Providing Uncertainty Quantitation and Improved Interpretability
Jonathan Parkinson and Wei Wang
Journal of Chemical Information and Modeling 2023 63 (15), 4589-4601
DOI: 10.1021/acs.jcim.3c00601 

OR the preprint:

Jonathan Parkinson, & Wei Wang. (2023). Linear-Scaling Kernels for Protein Sequences and Small Molecules Outperform Deep Learning
While Providing Uncertainty Quantitation and Improved Interpretability.
`https://arxiv.org/abs/2302.03294 <https://arxiv.org/abs/2302.03294>`_



* :ref:`search`
